(nxml-define-char-name-set 'deseret
  '(("DESERET CAPITAL LETTER LONG I" #x10400)
    ("DESERET CAPITAL LETTER LONG E" #x10401)
    ("DESERET CAPITAL LETTER LONG A" #x10402)
    ("DESERET CAPITAL LETTER LONG AH" #x10403)
    ("DESERET CAPITAL LETTER LONG O" #x10404)
    ("DESERET CAPITAL LETTER LONG OO" #x10405)
    ("DESERET CAPITAL LETTER SHORT I" #x10406)
    ("DESERET CAPITAL LETTER SHORT E" #x10407)
    ("DESERET CAPITAL LETTER SHORT A" #x10408)
    ("DESERET CAPITAL LETTER SHORT AH" #x10409)
    ("DESERET CAPITAL LETTER SHORT O" #x1040A)
    ("DESERET CAPITAL LETTER SHORT OO" #x1040B)
    ("DESERET CAPITAL LETTER AY" #x1040C)
    ("DESERET CAPITAL LETTER OW" #x1040D)
    ("DESERET CAPITAL LETTER WU" #x1040E)
    ("DESERET CAPITAL LETTER YEE" #x1040F)
    ("DESERET CAPITAL LETTER H" #x10410)
    ("DESERET CAPITAL LETTER PEE" #x10411)
    ("DESERET CAPITAL LETTER BEE" #x10412)
    ("DESERET CAPITAL LETTER TEE" #x10413)
    ("DESERET CAPITAL LETTER DEE" #x10414)
    ("DESERET CAPITAL LETTER CHEE" #x10415)
    ("DESERET CAPITAL LETTER JEE" #x10416)
    ("DESERET CAPITAL LETTER KAY" #x10417)
    ("DESERET CAPITAL LETTER GAY" #x10418)
    ("DESERET CAPITAL LETTER EF" #x10419)
    ("DESERET CAPITAL LETTER VEE" #x1041A)
    ("DESERET CAPITAL LETTER ETH" #x1041B)
    ("DESERET CAPITAL LETTER THEE" #x1041C)
    ("DESERET CAPITAL LETTER ES" #x1041D)
    ("DESERET CAPITAL LETTER ZEE" #x1041E)
    ("DESERET CAPITAL LETTER ESH" #x1041F)
    ("DESERET CAPITAL LETTER ZHEE" #x10420)
    ("DESERET CAPITAL LETTER ER" #x10421)
    ("DESERET CAPITAL LETTER EL" #x10422)
    ("DESERET CAPITAL LETTER EM" #x10423)
    ("DESERET CAPITAL LETTER EN" #x10424)
    ("DESERET CAPITAL LETTER ENG" #x10425)
    ("DESERET SMALL LETTER LONG I" #x10428)
    ("DESERET SMALL LETTER LONG E" #x10429)
    ("DESERET SMALL LETTER LONG A" #x1042A)
    ("DESERET SMALL LETTER LONG AH" #x1042B)
    ("DESERET SMALL LETTER LONG O" #x1042C)
    ("DESERET SMALL LETTER LONG OO" #x1042D)
    ("DESERET SMALL LETTER SHORT I" #x1042E)
    ("DESERET SMALL LETTER SHORT E" #x1042F)
    ("DESERET SMALL LETTER SHORT A" #x10430)
    ("DESERET SMALL LETTER SHORT AH" #x10431)
    ("DESERET SMALL LETTER SHORT O" #x10432)
    ("DESERET SMALL LETTER SHORT OO" #x10433)
    ("DESERET SMALL LETTER AY" #x10434)
    ("DESERET SMALL LETTER OW" #x10435)
    ("DESERET SMALL LETTER WU" #x10436)
    ("DESERET SMALL LETTER YEE" #x10437)
    ("DESERET SMALL LETTER H" #x10438)
    ("DESERET SMALL LETTER PEE" #x10439)
    ("DESERET SMALL LETTER BEE" #x1043A)
    ("DESERET SMALL LETTER TEE" #x1043B)
    ("DESERET SMALL LETTER DEE" #x1043C)
    ("DESERET SMALL LETTER CHEE" #x1043D)
    ("DESERET SMALL LETTER JEE" #x1043E)
    ("DESERET SMALL LETTER KAY" #x1043F)
    ("DESERET SMALL LETTER GAY" #x10440)
    ("DESERET SMALL LETTER EF" #x10441)
    ("DESERET SMALL LETTER VEE" #x10442)
    ("DESERET SMALL LETTER ETH" #x10443)
    ("DESERET SMALL LETTER THEE" #x10444)
    ("DESERET SMALL LETTER ES" #x10445)
    ("DESERET SMALL LETTER ZEE" #x10446)
    ("DESERET SMALL LETTER ESH" #x10447)
    ("DESERET SMALL LETTER ZHEE" #x10448)
    ("DESERET SMALL LETTER ER" #x10449)
    ("DESERET SMALL LETTER EL" #x1044A)
    ("DESERET SMALL LETTER EM" #x1044B)
    ("DESERET SMALL LETTER EN" #x1044C)
    ("DESERET SMALL LETTER ENG" #x1044D)
    ))

;; arch-tag: 0fbf6586-41cf-41b2-88e9-d113db5d933e
